@@ -1,8 +1,17 @@
-/**
+/*
+    Copyright (c) 2006-2008 by amdfanatyk <amdfanatyk@o2.pl>
 
-	last.fm window
+    *************************************************************************
+    *                                                                       *
+    * This program is free software; you can redistribute it and/or modify  *
+    * it under the terms of the GNU General Public License as published by  *
+    * the Free Software Foundation; either version 2 of the License, or     *
+    * (at your option) any later version.                                   *
+    *                                                                       *
+    *************************************************************************
+*/
 
-**/
+#include "qmslider.h"
 
 #include <qmessagebox.h>
 
