@@ -1,12 +1,15 @@
-/**
+/*
+    Copyright (c) 2006-2008 by amdfanatyk <amdfanatyk@o2.pl>
 
-	playlist.cpp
-
-	Playlists' engine source file
-
-**/
-
-#ifndef PLAYLIST_H
+    *************************************************************************
+    *                                                                       *
+    * This program is free software; you can redistribute it and/or modify  *
+    * it under the terms of the GNU General Public License as published by  *
+    * the Free Software Foundation; either version 2 of the License, or     *
+    * (at your option) any later version.                                   *
+    *                                                                       *
+    *************************************************************************
+*/
 
 #include <qfile.h>
 
@@ -921,5 +924,3 @@ void Playlist::shuffle(pListIndex * const index)
 		swap(index, previous, item->myId->current);
 	}
 }
-
-#endif
