@@ -1,3 +1,16 @@
+/*
+    Copyright (c) 2006-2008 by amdfanatyk <amdfanatyk@o2.pl>
+
+    *************************************************************************
+    *                                                                       *
+    * This program is free software; you can redistribute it and/or modify  *
+    * it under the terms of the GNU General Public License as published by  *
+    * the Free Software Foundation; either version 2 of the License, or     *
+    * (at your option) any later version.                                   *
+    *                                                                       *
+    *************************************************************************
+*/
+
 #ifndef TYPES_H
 #define TYPES_H
 
@@ -17,6 +30,7 @@ enum ItemWithAccel
 	TRAY_STOP,
 	TRAY_LEFT,
 	TRAY_RIGHT,
+	TRAY_QUIT,
 	WND_NEWPLAYLIST,
 	WND_UP,
 	WND_DOWN,
@@ -28,6 +42,7 @@ enum ItemWithAccel
 	CONTEXT_LASTFM,
 	CONTEXT_EQUALIZER,
 	CONTEXT_SOUND,
+	CONTEXT_RELOADMETA,
 	CONTEXT_ACCELS,
 	CONTEXT_SAVE,
 	CONTEXT_RMBOTH,
